# Org.OpenAPITools - the C# library for the Data API

Cognitive Credit Company Data API

This C# SDK is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.0.0
- SDK version: 1.0.0
- Build package: org.openapitools.codegen.languages.CSharpNetCoreClientCodegen

<a id="frameworks-supported"></a>
## Frameworks supported
- .NET Core >=1.0
- .NET Framework >=4.6
- Mono/Xamarin >=vNext

<a id="dependencies"></a>
## Dependencies

- [RestSharp](https://www.nuget.org/packages/RestSharp) - 106.13.0 or later
- [Json.NET](https://www.nuget.org/packages/Newtonsoft.Json/) - 13.0.2 or later
- [JsonSubTypes](https://www.nuget.org/packages/JsonSubTypes/) - 1.8.0 or later
- [System.ComponentModel.Annotations](https://www.nuget.org/packages/System.ComponentModel.Annotations) - 5.0.0 or later

The DLLs included in the package may not be the latest version. We recommend using [NuGet](https://docs.nuget.org/consume/installing-nuget) to obtain the latest version of the packages:
```
Install-Package RestSharp
Install-Package Newtonsoft.Json
Install-Package JsonSubTypes
Install-Package System.ComponentModel.Annotations
```

NOTE: RestSharp versions greater than 105.1.0 have a bug which causes file uploads to fail. See [RestSharp#742](https://github.com/restsharp/RestSharp/issues/742).
NOTE: RestSharp for .Net Core creates a new socket for each api call, which can lead to a socket exhaustion problem. See [RestSharp#1406](https://github.com/restsharp/RestSharp/issues/1406).

<a id="installation"></a>
## Installation
Generate the DLL using your preferred tool (e.g. `dotnet build`)

Then include the DLL (under the `bin` folder) in the C# project, and use the namespaces:
```csharp
using Org.OpenAPITools.Api;
using Org.OpenAPITools.Client;
using Org.OpenAPITools.Model;
```
<a id="usage"></a>
## Usage

To use the API client with a HTTP proxy, setup a `System.Net.WebProxy`
```csharp
Configuration c = new Configuration();
System.Net.WebProxy webProxy = new System.Net.WebProxy("http://myProxyUrl:80/");
webProxy.Credentials = System.Net.CredentialCache.DefaultCredentials;
c.Proxy = webProxy;
```

<a id="getting-started"></a>
## Getting Started

```csharp
using System.Collections.Generic;
using System.Diagnostics;
using Org.OpenAPITools.Api;
using Org.OpenAPITools.Client;
using Org.OpenAPITools.Model;

namespace Example
{
    public class Example
    {
        public static void Main()
        {

            Configuration config = new Configuration();
            config.BasePath = "https://cognitivecreditapi.com/v1";
            // Configure API key authorization: authorizeClient
            config.ApiKey.Add("x-api-key", "YOUR_API_KEY");
            // Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
            // config.ApiKeyPrefix.Add("x-api-key", "Bearer");

            var apiInstance = new DefaultApi(config);
            var interval = "interval_example";  // string | identifier for the interval of comparables data to fetch
            var atTimestamp = DateTime.Parse("2013-10-20T19:20:30+01:00");  // DateTime? | ISO-8601 Timestamp to return comparables snapshot for (optional) 
            var companyIds = "companyIds_example";  // string | filter by supplied company ids (optional) 
            var limit = 56;  // int? | maximum number of results to return - typically used when paging (optional) 
            var continuationToken = "continuationToken_example";  // string | identifier of last result in previous result set - allows continuation of paged results (optional) 
            var acceptEncoding = "\"gzip, deflate, br\"";  // string | client supported encodings (gzip, deflate, br) (optional)  (default to "gzip, deflate, br")

            try
            {
                // Get company comparables
                ComparablesResponse result = apiInstance.ApiConsumerProjectLocalGetCompanyComparablesSubtypes(interval, atTimestamp, companyIds, limit, continuationToken, acceptEncoding);
                Debug.WriteLine(result);
            }
            catch (ApiException e)
            {
                Debug.Print("Exception when calling DefaultApi.ApiConsumerProjectLocalGetCompanyComparablesSubtypes: " + e.Message );
                Debug.Print("Status Code: "+ e.ErrorCode);
                Debug.Print(e.StackTrace);
            }

        }
    }
}
```

<a id="documentation-for-api-endpoints"></a>
## Documentation for API Endpoints

All URIs are relative to *https://cognitivecreditapi.com/v1*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*DefaultApi* | [**ApiConsumerProjectLocalGetCompanyComparablesSubtypes**](docs/DefaultApi.md#apiconsumerprojectlocalgetcompanycomparablessubtypes) | **GET** /comparables/{interval} | Get company comparables
*DefaultApi* | [**ApiConsumerProjectLocalGetCompanyDatapoint**](docs/DefaultApi.md#apiconsumerprojectlocalgetcompanydatapoint) | **GET** /datapoints/{datapointId} | Get a company datapoint
*DefaultApi* | [**ApiConsumerProjectLocalGetCompanyFinancials**](docs/DefaultApi.md#apiconsumerprojectlocalgetcompanyfinancials) | **GET** /companies/{companyId}/financials | Get company financials
*DefaultApi* | [**ApiConsumerProjectLocalGetCompanyListings**](docs/DefaultApi.md#apiconsumerprojectlocalgetcompanylistings) | **GET** /companies | Get company descriptions
*DefaultApi* | [**ApiConsumerProjectLocalGetCompanyTimeSeries**](docs/DefaultApi.md#apiconsumerprojectlocalgetcompanytimeseries) | **GET** /companies/{companyId}/timeseries/{tag}/{interval} | Get company time series
*DefaultApi* | [**ApiConsumerProjectLocalGetComparablesUpdatesSince**](docs/DefaultApi.md#apiconsumerprojectlocalgetcomparablesupdatessince) | **GET** /comparables/updates | Get company comparables updates for a given time period
*DefaultApi* | [**ApiConsumerProjectLocalGetPeriodDates**](docs/DefaultApi.md#apiconsumerprojectlocalgetperioddates) | **GET** /companies/{companyId}/periods | Get company period dates


<a id="documentation-for-models"></a>
## Documentation for Models

 - [Model.CommentRefsInner](docs/CommentRefsInner.md)
 - [Model.CompanyDatapointResponse](docs/CompanyDatapointResponse.md)
 - [Model.CompanyDatapointResponseData](docs/CompanyDatapointResponseData.md)
 - [Model.CompanyDescriptionResponse](docs/CompanyDescriptionResponse.md)
 - [Model.CompanyDescriptionResponseMeta](docs/CompanyDescriptionResponseMeta.md)
 - [Model.CompanyFinancialsResponse](docs/CompanyFinancialsResponse.md)
 - [Model.CompanyFinancialsResponseData](docs/CompanyFinancialsResponseData.md)
 - [Model.CompanyPeriodDatesResponse](docs/CompanyPeriodDatesResponse.md)
 - [Model.CompanyPeriodDatesResponseData](docs/CompanyPeriodDatesResponseData.md)
 - [Model.CompanyTimeSeriesResponse](docs/CompanyTimeSeriesResponse.md)
 - [Model.CompanyTimeSeriesResponseData](docs/CompanyTimeSeriesResponseData.md)
 - [Model.ComparablesInner](docs/ComparablesInner.md)
 - [Model.ComparablesResponse](docs/ComparablesResponse.md)
 - [Model.DataInner](docs/DataInner.md)
 - [Model.DataInner1](docs/DataInner1.md)
 - [Model.DataInner2](docs/DataInner2.md)
 - [Model.FinancialsInner](docs/FinancialsInner.md)
 - [Model.Multiplier](docs/Multiplier.md)
 - [Model.PartsInner](docs/PartsInner.md)
 - [Model.PeriodDatesInner](docs/PeriodDatesInner.md)
 - [Model.TimeSeriesInner](docs/TimeSeriesInner.md)


<a id="documentation-for-authorization"></a>
## Documentation for Authorization


Authentication schemes defined for the API:
<a id="authorizeClient"></a>
### authorizeClient

- **Type**: API key
- **API key parameter name**: x-api-key
- **Location**: HTTP header

